aboutsummaryrefslogtreecommitdiffstats
path: root/src/gos/gos_osx.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/gos/gos_osx.c')
-rw-r--r--src/gos/gos_osx.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/gos/gos_osx.c b/src/gos/gos_osx.c
index 56d64d98..a09647ee 100644
--- a/src/gos/gos_osx.c
+++ b/src/gos/gos_osx.c
@@ -132,7 +132,7 @@ void gfxSemDestroy(gfxSem *pSem) {
pthread_cond_destroy(&pSem->cond);
}
-bool_t gfxSemWait(gfxSem *pSem, delaytime_t ms) {
+gBool gfxSemWait(gfxSem *pSem, delaytime_t ms) {
pthread_mutex_lock(&pSem->mtx);
switch (ms) {
case TIME_INFINITE:
@@ -142,7 +142,7 @@ bool_t gfxSemWait(gfxSem *pSem, delaytime_t ms) {
case TIME_IMMEDIATE:
if (!pSem->cnt) {
pthread_mutex_unlock(&pSem->mtx);
- return FALSE;
+ return gFalse;
}
break;
default:
@@ -156,11 +156,11 @@ bool_t gfxSemWait(gfxSem *pSem, delaytime_t ms) {
while (!pSem->cnt) {
// We used to test the return value for ETIMEDOUT. This doesn't
// work in some current pthread libraries which return -1 instead
// and set errno to ETIMEDOUT. So, we will return FALSE on any error
// including a ETIMEDOUT.
if (pthread_cond_timedwait(&pSem->cond, &pSem->mtx, &tm)) {
pthread_mutex_unlock(&pSem->mtx);
- return FALSE;
+ return gFalse;
}
}
}
@@ -168,7 +168,7 @@ bool_t gfxSemWait(gfxSem *pSem, delaytime_t ms) {
}
pSem->cnt--;
pthread_mutex_unlock(&pSem->mtx);
- return TRUE;
+ return gTrue;
}
void gfxSemSignal(gfxSem *pSem) {
@@ -156,11 +156,11 @@ bool_t gfxSemWait(gfxSem *pSem, delaytime_t ms) {
// We used to test the return value for ETIMEDOUT. This doesn't
// work in some current pthread libraries which return -1 instead
- // and set errno to ETIMEDOUT. So, we will return FALSE on any error
+ // and set errno to ETIMEDOUT. So, we will return gFalse on any error
// including a ETIMEDOUT.
if (pthread_cond_timedwait(&pSem->cond, &pSem->mtx, &tm)) {